@@ -32,6 +32,7 @@ struct ClassMeta {
 
   SV *name;
   HV *stash;
+  AV *isa;             /* cached pointer to the @ISA array for the stash */
   AV *pending_submeta; /* NULL, or AV containing raw ClassMeta pointers to subclasses pending seal */
   AV *hooks;           /* NULL, or AV of raw pointers directly to ClassHook structs */
   AV *fields;          /* each elem is a raw pointer directly to a FieldMeta */
@@ -47,6 +48,7 @@ struct ClassMeta {
 
   COP *tmpcop;         /* a COP to use during generated constructor */
   CV *methodscope;     /* a temporary CV used just during compilation of a `method` */
+  U32 methodscope_seq; /* PL_cop_seqmax at the time methodscope was created */
 
   SuspendedCompCVBuffer initfields_compcv; /* temporary PL_compcv + associated state during initfields */
   OP *initfields_lines;                    /* temporary OP_LINESEQ to contain the initfield ops */
